@@ -35,8 +35,8 @@ VideoIDList  = Sequence[VideoID]
 
 class AnalysisType(str, Enum):
     EDGE_CASE      = "edge_case"
-    SEARCH         = "search"
-    RAPID_REVIEW   = "rapid_review" 
+    RAPID_REVIEW   = "rapid_review"
+    SEARCH         = "search"  # DEPRECATED - kept for backwards compatibility 
 
 class CustomCategory(str, Enum):
     DRIVING        = "driving"
@@ -630,12 +630,24 @@ class VideoClient:
                          edge_case_category: str | None,
                          custom_category: CustomCategory | str | None):
         """Ensure required kwargs are provided for each analysis type."""
+        # Check for deprecated 'search' analysis type or search_query parameter
+        if analysis_type == "search" or search_query:
+            import warnings
+            warnings.warn(
+                "analysis_type='search' and search_query parameter are deprecated and have been removed. "
+                "Use analysis_type='rapid_review' with custom_event parameter instead "
+                "for searching in videos of any length.",
+                DeprecationWarning,
+                stacklevel=3
+            )
+            raise ValueError(
+                "analysis_type='search' and search_query parameter have been removed. "
+                "Use analysis_type='rapid_review' with custom_event=<your_search_query> instead."
+            )
+        
         if analysis_type is None or analysis_type not in [cat.value for cat in AnalysisType]:
             valid_values = ", ".join([f"'{cat.value}'" for cat in AnalysisType])
-            raise ValueError(f"analysis_type must be one of {valid_values}")        
-
-        if search_query and analysis_type != AnalysisType.SEARCH:
-            raise ValueError("search_query is only allowed when analysis_type='search'")
+            raise ValueError(f"analysis_type must be one of {valid_values}")
         if custom_event and analysis_type != AnalysisType.RAPID_REVIEW:
             raise ValueError("custom_event is only allowed when analysis_type='rapid_review'")
         if edge_case_category and analysis_type != AnalysisType.EDGE_CASE:
@@ -643,8 +655,6 @@ class VideoClient:
         if custom_category and analysis_type != AnalysisType.RAPID_REVIEW:
             raise ValueError("custom_category is only allowed when analysis_type='rapid_review'")
 
-        if analysis_type == AnalysisType.SEARCH and not search_query:
-            raise ValueError("search_query is required when analysis_type='search'")
         if analysis_type == AnalysisType.RAPID_REVIEW and not custom_event:
             raise ValueError("custom_event is required when analysis_type='rapid_review'")
         if analysis_type == AnalysisType.EDGE_CASE and not edge_case_category:
@@ -677,15 +687,6 @@ class VideoClient:
                         custom_category=custom_category)
 
         # 2) dispatch by AnalysisType
-        if analysis_type == AnalysisType.SEARCH:
-            sweep = self.search_events(video_id, search_query, model_id=model_id,
-                                    timeout=timeout)
-            return {
-                "video_id": video_id,
-                "mode":     "search",
-                "status":   "completed",
-                "hits":     sweep.get("hits", []),
-            }
 
         if analysis_type == AnalysisType.RAPID_REVIEW:
             response = self._custom_event_detection(
@@ -1156,32 +1157,21 @@ class VideoClient:
         # The response should already be in the correct format
         return resp.json()
     
-    ############### 
-    # ──────────────── Long Video Event Search ────────────────────────────────────────
+    ###############
+    # ──────────────── Deprecated Methods ────────────────────────────────────────
     ###############
 
     def apply_search(self, parent_id: str, query: str,
                     model_id: str = "Nomadic-VL-XLarge") -> Dict[str, Any]:
-        payload = {
-            "query":      query,
-            "model_id":   model_id,
-            "collection": self.client.collection_name,
-        }
-        r = self.client._make_request(
-            "POST", f"/api/videos/{parent_id}/apply-search", data=payload
+        """
+        DEPRECATED: This method has been removed.
+        Use analyze() with analysis_type='rapid_review' instead.
+        """
+        raise NomadicMLError(
+            "apply_search has been deprecated. Use analyze() with analysis_type='rapid_review' instead, "
+            "which now supports all video lengths including long videos."
         )
-        if r.status_code >= 400:
-            raise NomadicMLError(format_error_message(r.json()))
-        return r.json()                       # {"sweep_id": "...", ...}
 
-    def get_sweep_status(self, parent_id: str, sweep_id: str) -> Dict[str, Any]:
-        params = {"collection": self.client.collection_name}
-        r = self.client._make_request(
-            "GET", f"/api/videos/{parent_id}/sweeps/{sweep_id}", params=params
-        )
-        if r.status_code >= 400:
-            raise NomadicMLError(format_error_message(r.json()))
-        return r.json()
 
     def _get_analysis_status(self, video_id: str, analysis_id: str) -> Dict[str, Any]:
         """Get the current status of a rapid review analysis."""
@@ -1193,21 +1183,6 @@ class VideoClient:
             raise NomadicMLError(format_error_message(r.json()))
         return r.json()
 
-    def wait_for_search(self, parent_id: str, sweep_id: str,
-                        timeout: int = 1_800, poll_interval: int = 5) -> Dict[str, Any]:
-        start = time.time()
-        while True:
-            p = self.get_sweep_status(parent_id, sweep_id)
-            status = (p.get("status") or "").upper()
-            progress = int(p.get("progress", 0))
-            self._print_status_bar(sweep_id,
-                        percent=progress,
-                        status="SEARCH")
-            if status in {"SUCCEEDED", "FAILED"}:
-                return p
-            if time.time() - start > timeout:
-                raise TimeoutError(f"Sweep {sweep_id} timed-out after {timeout}s")
-            time.sleep(poll_interval)
 
     def _wait_for_rapid_review(self, video_id: str, analysis_id: str,
                               timeout: int = 3_600, poll_interval: int = 5,
@@ -1277,12 +1252,6 @@ class VideoClient:
                 raise TimeoutError(f"Rapid review {analysis_id} timed-out after {timeout}s")
             time.sleep(poll_interval)
 
-    def search_events(self, parent_id: str, query: str, *,
-                    model_id: str = "Nomadic-VL-XLarge",
-                    timeout: int = 1_800, poll_interval: int = 5) -> Dict[str, Any]:
-        sweep = self.apply_search(parent_id, query, model_id)
-        return self.wait_for_search(parent_id, sweep["sweep_id"],
-                                    timeout=timeout, poll_interval=poll_interval)
 
     def my_videos(self, folder_id: str | None = None) -> List[Dict[str, Any]]:
         params = {
